==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/keywords.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once "init_processor.php";
if ($_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
//session_regenerate_id(TRUE);
?>
<?php
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
?>
<?php
//NULL バイトの入力を弾く
checkNull($_GET);
//長すぎる検索ワード
if ($_GET["word"] != '') checkWord($_GET["word"]);
if ($_GET['related'] != '') checkWord($_GET['related']);
//不正なはてなID
if ($_GET["user"] != '') checkId($_GET["user"]);
//不正な page
if ($_GET['page'] != '') checkPagenum($_GET[page]);
?>
<?php
//
// require 'login_processor.php';
?>
<?php
if ($_GET['word'] != ''){
  $get_word = $_GET['word'];
  $json_url = $api_base_url.'keywords/list.xml?word=' . rawurlencode($get_word).'&without_related_keywords=1';
  $page_head = htmlspecialchars($get_word, ENT_QUOTES) . ' に一致するキーワード';
  $self_anchor = './keywords.php?word=' . rawurlencode(htmlspecialchars($get_word, ENT_QUOTES));
  $list_mode = 'search';
} elseif ($_GET['user'] != ''){
  $get_user = $_GET['user'];
  $json_url = $api_base_url.'statuses/keywords/' . $get_user . '.xml'.'?without_related_keywords=1';
  $page_head = htmlspecialchars($get_user, ENT_QUOTES) . ' のお気に入りキーワード';
  $self_anchor = './keywords.php?user=' . $get_user;
  $list_mode = 'following';
} elseif($_GET['related'] != ''){
  $get_related = $_GET['related'];
  $json_url = $api_base_url.'keywords/show/'.$get_related.'.xml';
  $page_head = htmlspecialchars($get_related, ENT_QUOTES).' の関連キーワード';
  $self_anchor = './keywords.php?related='.$get_related;
  $list_mode = 'related';
} else {
  $json_url = $api_base_url.'keywords/list.xml'.'?without_related_keywords=1';
  $page_head = 'キーワード一覧';
  $self_anchor = './keywords.php';
  $list_mode = 'default';
}
if ($_GET['page'] != ''){
	if ($list_mode == 'default' or 'related'){
		$self_anchor_possibly_with_pagenum = $self_anchor . '?page=' . $_GET['page'];
	} else {
		$self_anchor_possibly_with_pagenum = $self_anchor . '&amp;page=' . $_GET['page'];
	}
	$relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
	$relogin = $self_anchor_possibly_with_pagenum . '&amp;with=haiku&amp;callback='.rawurlencode($relog_back);
} else {
	$self_anchor_possibly_with_pagenum = $self_anchor;
	if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != ''){
	  $relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
	  $relogin = $self_anchor_possibly_with_pagenum . '&amp;with=haiku&amp;callback='.rawurlencode($relog_back);
	} else {
	  $relog_back = $self_anchor_possibly_with_pagenum . '?log=try';
	  $relogin = $self_anchor_possibly_with_pagenum . '?with=haiku&amp;callback='.rawurlencode($relog_back);
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name}{$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
//var_dump($_GET);
// echoCommonHeader($relogin);
echo "<div id=\"header\" class=\"keywords\">\n";
echo "<h1 id=\"entries-head\" class=\"head1\">{$page_head}</h1>\n<hr />";
echo "</div>\n";
?>
<div class="contents">
<ul>
<li><form method="get" action="./keywords.php" accept-charset="UTF-8">
<label for="go2keyword">キーワード</label><input type="text" name="word" maxlength="170" id="go2keyword" /><label for="go2keyword">を</label>
<?php if ($_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />'; ?>
<input type="submit" value="検索" />
</form></li>
<?php
if ($_GET["page"] != ''){
	if ($get_word != ''){
		$request_url = $json_url . "&page=" . htmlspecialchars($_GET["page"], ENT_QUOTES);
	}	elseif ($get_user != ''){
			$request_url = $json_url . "&page=" . htmlspecialchars($_GET["page"], ENT_QUOTES);
	}	else {
			$request_url = $json_url . '&page=' . htmlspecialchars($_GET['page'], ENT_QUOTES);
	}
}	else {
	$request_url = $json_url;
}
//var_dump($request_url);
/*if ($kw_cache_dir == ''){
  $use_cache = FALSE;
} elseif (isset($_GET['reload']) && $_GET['reload'] == 'force'){
	$use_cache = FALSE;
} elseif ($kw_cache_dir != ''){
	$use_cache = TRUE;
} else {
	$use_cache = FALSE;
}*/
require_once 'keywords_processor.php';
?>
</ul><hr />
</div>
<?php
$navi_paging = TRUE;
$navi_imaging = FALSE;
require 'footer_include.php';
?>
</body>
</html>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/keywords.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2010 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php
define("HELLO","world");
require_once "product_definitions.php";
require_once "configurable_variables.php";
require_once "common_functions.php";
?>
<?php
require_once "init_processor.php";
if (!isset($_SESSION['auth']) || $_SESSION['auth'] != TRUE){
// if ($_SESSION['image'] != 'on'){
  $_SESSION = array();
  if (isset($_COOKIE[session_name()])){
	setcookie(session_name(), '', time() - 42000, dirname($_SERVER['SCRIPT_NAME']) . '/', $_SERVER["SERVER_NAME"]);
  }
  session_destroy();
// }
}
//session_regenerate_id(TRUE);
?>
<?php
$selfcall = htmlspecialchars($_SERVER["PHP_SELF"], ENT_QUOTES);
$safequery = htmlspecialchars($_SERVER["QUERY_STRING"], ENT_QUOTES);
?>
<?php
//長すぎる検索ワード
if (isset($_GET["word"])) checkWord($_GET["word"]);
if (isset($_GET['related'])) checkWord($_GET['related']);
//不正なはてなID
if (isset($_GET["user"])) checkId($_GET["user"]);
//不正な page
if (isset($_GET['page'])) checkPagenum($_GET['page']);
?>
<?php
//
// require 'login_processor.php';
?>
<?php
if (isset($_GET['word']) && $_GET['word'] != ''){
  $get_word = $_GET['word'];
  $json_url = $api_base_url.'keywords/list.xml?word=' . rawurlencode($get_word).'&without_related_keywords=1';
  $page_head = htmlspecialchars($get_word, ENT_QUOTES) . ' に一致するキーワード';
  $self_anchor = './keywords.php?word=' . rawurlencode(htmlspecialchars($get_word, ENT_QUOTES));
  $list_mode = 'search';
} elseif (isset($_GET['user']) && $_GET['user'] != ''){
  $get_user = $_GET['user'];
  $json_url = $api_base_url.'statuses/keywords/' . $get_user . '.xml'.'?without_related_keywords=1';
  $page_head = htmlspecialchars($get_user, ENT_QUOTES) . ' のお気に入りキーワード';
  $self_anchor = './keywords.php?user=' . $get_user;
  $list_mode = 'following';
} elseif(isset($_GET['related']) && $_GET['related'] != ''){
  $get_related = $_GET['related'];
  $json_url = $api_base_url.'keywords/show/'.$get_related.'.xml';
  $page_head = htmlspecialchars($get_related, ENT_QUOTES).' の関連キーワード';
  $self_anchor = './keywords.php?related='.$get_related;
  $list_mode = 'related';
} else {
  $json_url = $api_base_url.'keywords/list.xml'.'?without_related_keywords=1';
  $page_head = 'キーワード一覧';
  $self_anchor = './keywords.php';
  $list_mode = 'default';
}
if (isset($_GET['page']) && $_GET['page'] != ''){
	if ($list_mode == 'default' || $list_mode = 'related'){
		$self_anchor_possibly_with_pagenum = $self_anchor . '?page=' . $_GET['page'];
	} else {
		$self_anchor_possibly_with_pagenum = $self_anchor . '&amp;page=' . $_GET['page'];
	}
	$relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
	$relogin = $self_anchor_possibly_with_pagenum . '&amp;with=haiku&amp;callback='.rawurlencode($relog_back);
} else {
	$self_anchor_possibly_with_pagenum = $self_anchor;
	if (isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING'] != ''){
	  $relog_back = $self_anchor_possibly_with_pagenum . '&log=try';
	  $relogin = $self_anchor_possibly_with_pagenum . '&amp;with=haiku&amp;callback='.rawurlencode($relog_back);
	} else {
	  $relog_back = $self_anchor_possibly_with_pagenum . '?log=try';
	  $relogin = $self_anchor_possibly_with_pagenum . '?with=haiku&amp;callback='.rawurlencode($relog_back);
	}
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
   "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ja" lang="ja">
<head>
	<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
	<meta http-equiv="Content-Style-Type" content="text/css" />
	<meta http-equiv="Content-Script-Type" content="text/javascript" />
	<?php echo "<title>{$page_head} - {$site_name}{$site_name_caption}</title>\n"; ?>
	<link rel="stylesheet" href="<?php echo $style_sheet; ?>" />
	<link rel="icon" href="./favicon.ico" type="image/vnd.microsoft.icon" />
	<link rel="shortcut icon" href="./favicon.ico" type="image/vnd.microsoft.icon" /></head>
<body>
<?php
//var_dump($_GET);
// echoCommonHeader($relogin);
echo "<div id=\"header\" class=\"keywords\">\n";
echo "<h1 id=\"entries-head\" class=\"head1\">{$page_head}</h1>\n<hr />";
echo "</div>\n";
?>
<div class="contents">
<ul>
<li><form method="get" action="./keywords.php" accept-charset="UTF-8">
<label for="go2keyword">キーワード</label><input type="text" name="word" maxlength="170" id="go2keyword" /><label for="go2keyword">を</label>
<?php if (isset($_GET['image']) && $_GET['image'] == 'on') echo '<input type="hidden" name="image" value="on" />'; ?>
<input type="submit" value="検索" />
</form></li>
<?php
if (isset($_GET["page"]) && $_GET["page"] != ''){
	if (isset($get_word) && $get_word != ''){
		$request_url = $json_url . "&page=" . htmlspecialchars($_GET["page"], ENT_QUOTES);
	}	elseif (isset($get_user) && $get_user != ''){
			$request_url = $json_url . "&page=" . htmlspecialchars($_GET["page"], ENT_QUOTES);
	}	else {
			$request_url = $json_url . '&page=' . htmlspecialchars($_GET['page'], ENT_QUOTES);
	}
}	else {
	$request_url = $json_url;
}
//var_dump($request_url);
/*if ($kw_cache_dir == ''){
  $use_cache = FALSE;
} elseif (isset($_GET['reload']) && $_GET['reload'] == 'force'){
	$use_cache = FALSE;
} elseif ($kw_cache_dir != ''){
	$use_cache = TRUE;
} else {
	$use_cache = FALSE;
}*/
require_once 'keywords_processor.php';
?>
</ul><hr />
</div>
<?php
$navi_paging = TRUE;
$navi_imaging = FALSE;
require 'footer_include.php';
?>
</body>
</html>
